@@ -112,7 +112,7 @@ def commit(
     f.write(message.encode("utf-8"))
     f.close()
 
-    command = f"git commit {args} -F {f.name}"
+    command = f'git commit {args} -F "{f.name}"'
 
     if committer_date and os.name == "nt":  # pragma: no cover
         # Using `cmd /v /c "{command}"` sets environment variables only for that command
@@ -175,7 +175,9 @@ def get_tags(
         f'%(object)"'
     )
     extra = "--merged" if reachable_only else ""
-    c = cmd.run(f"git tag --format={formatter} --sort=-creatordate {extra}")
+    # Force the default language for parsing
+    env = {"LC_ALL": "C", "LANG": "C", "LANGUAGE": "C"}
+    c = cmd.run(f"git tag --format={formatter} --sort=-creatordate {extra}", env=env)
     if c.return_code != 0:
         if reachable_only and c.err == "fatal: malformed object name HEAD\n":
             # this can happen if there are no commits in the repo yet
